@@ -6,9 +6,8 @@ import glob
 import logging
 import os
 import datetime
+from google.cloud import translate_v2
 from urllib.parse import urlparse
-# https://selenium-python.readthedocs.io/api.html
-from selenium.common.exceptions import InvalidArgumentException
 
 import requests
 from bs4 import BeautifulSoup
@@ -71,7 +70,7 @@ class Article(object):
 
         if source_url == '':
             scheme = urls.get_scheme(url)
-            if scheme is None:
+            if scheme is None or scheme.strip() is '':
                 scheme = 'http'
             source_url = scheme + '://' + urls.get_domain(url)
 
@@ -175,7 +174,8 @@ class Article(object):
         on a source (scraper) level.
         """
         self.download()
-        self.parse()
+        if not self.is_parsed:
+            self.parse()
         if self.config.use_canonical_link and self.canonical_link and self.canonical_link != self.url:
             self.url = self.canonical_link
             # recurse once!
@@ -185,7 +185,6 @@ class Article(object):
         if url.find(".wikipedia.org/wiki/") >= 0:
             self.parse_tables(attributes={"class": "wikitable"})
 
-
     def _parse_scheme_file(self, path):
         try:
             with open(path, "r") as fin:
@@ -201,8 +200,6 @@ class Article(object):
             return html, pdf_file_reader
         except requests.exceptions.RequestException as ex:
             return self.failed_response(ex)
-        except InvalidArgumentException as ex:
-            return self.failed_response(ex)
         except Exception as ex:
             return self.failed_response(ex)
 
@@ -231,6 +228,8 @@ class Article(object):
                     creation_date = pdf_file_reader.documentInfo.getText("/CreationDate").replace("D:", "")
                     self.set_publish_date(parse_date_str(creation_date[0:8]))
                     self.set_text(html.strip())
+                    # don't bother parsing HTML later, there is no HTML here, just raw text
+                    self.is_parsed = True
             if html is None:
                 log.debug('Download failed on URL %s because of %s' %
                           (self.url, self.download_exception_msg))
@@ -313,8 +312,7 @@ class Article(object):
             self.top_node = self.extractor.post_cleanup(self.top_node)
             self.clean_top_node = copy.deepcopy(self.top_node)
 
-            text, article_html = output_formatter.get_formatted(
-                self.top_node)
+            text, article_html = output_formatter.get_formatted(self.top_node)
             self.set_article_html(article_html)
             self.set_text(text)
 
@@ -556,9 +554,18 @@ class Article(object):
 
     def set_text(self, text):
         if text:
-            text = cleanup_text(text.strip())
-            text = text.replace("  ", " ")
-            text = text[:self.config.MAX_TEXT]
+            # print(f"Scraper translate={self.config.translate} GOOGLE_APPLICATION_CREDENTIALS={os.environ.get('GOOGLE_APPLICATION_CREDENTIALS')}")
+            if self.config.translate is True and os.environ.get('GOOGLE_APPLICATION_CREDENTIALS'):
+                translator = translate_v2.Client()
+                raw_dict = translator.translate(text, target_language='en', format_="text")
+                text = raw_dict['translatedText']
+                text = text.replace("  ", " ")
+                text = text[:self.config.MAX_TEXT]
+                self.config._language = 'en'
+            elif self.meta_lang == 'en':
+                # text = cleanup_text(text.strip())
+                text = text.replace("  ", " ")
+                text = text[:self.config.MAX_TEXT]
             self.text = text
 
     def set_html(self, html):
